ImageTranslatorCNN - Convolutional Neural Network
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.cnn

.. autoclass:: ImageTranslatorCNN
    :members:
    :inherited-members:
